@@ -8,9 +8,9 @@ from .chess_dask_cluster import ChessDaskCluster
 class ControlHeatmap:
     "Class to generate the control heatmap based on the input PGN files"
 
-def generate_heatmap_images():
-    "Fetches the input from files and starts to analyze the games"
-    game_list = ChessUtil.get_games_from_pgn_files()
-    dask_cluster = ChessDaskCluster()
-    dask_cluster.analyse_games_in_cluster(game_list)
+    def generate_heatmap_images(self):
+        "Fetches the input from files and starts to analyze the games"
+        game_list = ChessUtil.get_games_from_pgn_files()
+        dask_cluster = ChessDaskCluster()
+        dask_cluster.analyse_games_in_cluster(game_list)
    
\ No newline at end of file
